@@ -70,7 +70,7 @@ npm install cdk-gitlab-runner@cdkv1
 
 ### Instance Type
 
-```typescript
+```python
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
 // If want change instance type to t3.large .
@@ -86,7 +86,7 @@ new GitlabContainerRunner(this, 'runner-instance', { gitlabtoken: '$GITLABTOKEN'
 
 If you want change what you want tag name .
 
-```typescript
+```python
 // If you want change  what  your self Gitlab Server Url .
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
@@ -100,7 +100,7 @@ new GitlabContainerRunner(this, 'runner-instance-change-tag', {
 
 If you want change what you want tag name .
 
-```typescript
+```python
 // If you want change  what  you want tag name .
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
@@ -114,7 +114,7 @@ new GitlabContainerRunner(this, 'runner-instance-change-tag', {
 
 If you want add runner other IAM Policy like s3-readonly-access.
 
-```typescript
+```python
 // If you want add runner other IAM Policy like s3-readonly-access.
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 import { ManagedPolicy } from '@aws-cdk/aws-iam';
@@ -132,7 +132,7 @@ runner.runnerRole.addManagedPolicy(
 
 If you want add runner other SG Ingress .
 
-```typescript
+```python
 // If you want add runner other SG Ingress .
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 import { Port, Peer } from '@aws-cdk/aws-ec2';
@@ -153,7 +153,7 @@ runner.defaultRunnerSG.connections.allowFrom(
 
 > 2020/06/27 , you can use your self exist VPC or new VPC , but please check your `vpc public Subnet` Auto-assign public IPv4 address must be Yes ,or `vpc private Subnet` route table associated `nat gateway` .
 
-```typescript
+```python
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 import { Port, Peer, Vpc, SubnetType } from '@aws-cdk/aws-ec2';
 import { ManagedPolicy } from '@aws-cdk/aws-iam';
@@ -182,7 +182,7 @@ const runner = new GitlabContainerRunner(this, 'testing', {
 
 > 2020/06/27 , you can use your self exist role assign to runner
 
-```typescript
+```python
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 import { Port, Peer } from '@aws-cdk/aws-ec2';
 import { ManagedPolicy, Role, ServicePrincipal } from '@aws-cdk/aws-iam';
@@ -206,7 +206,7 @@ runner.runnerRole.addManagedPolicy(
 
 > 2020/08/22 , you can change you want ebs size.
 
-```typescript
+```python
 import { GitlabContainerRunner } from 'cdk-gitlab-runner';
 
 new GitlabContainerRunner(stack, 'testing', {
@@ -219,7 +219,7 @@ new GitlabContainerRunner(stack, 'testing', {
 
 > 2020/11/25 , you can set the number of runners.
 
-```typescript
+```python
 import { GitlabRunnerAutoscaling } from 'cdk-gitlab-runner';
 
 new GitlabRunnerAutoscaling(stack, 'testing', {
@@ -234,7 +234,7 @@ new GitlabRunnerAutoscaling(stack, 'testing', {
 > 2020/08/27 , you can use spotfleet instance be your gitlab runner,
 > after create spotfleet instance will auto output instance id.
 
-```typescript
+```python
 import { GitlabContainerRunner, BlockDuration } from 'cdk-gitlab-runner';
 
 const runner = new GitlabContainerRunner(stack, 'testing', {
@@ -250,7 +250,7 @@ runner.expireAfter(Duration.hours(1));
 > 2020/11/19, you setting job runtime bind host volumes.
 > see more https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section
 
-```typescript
+```python
 import { GitlabContainerRunner, BlockDuration } from 'cdk-gitlab-runner';
 
 const runner = new GitlabContainerRunner(stack, 'testing', {
@@ -333,6 +333,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_autoscaling
@@ -470,6 +472,10 @@ class DockerVolumes:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DockerVolumes.__init__)
+            check_type(argname="argument container_path", value=container_path, expected_type=type_hints["container_path"])
+            check_type(argname="argument host_path", value=host_path, expected_type=type_hints["host_path"])
         self._values: typing.Dict[str, typing.Any] = {
             "container_path": container_path,
             "host_path": host_path,
@@ -575,6 +581,10 @@ class GitlabContainerRunner(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabContainerRunner.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabContainerRunnerProps(
             gitlabtoken=gitlabtoken,
             block_duration=block_duration,
@@ -612,6 +622,10 @@ class GitlabContainerRunner(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabContainerRunner.create_user_data)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument bucket_name", value=bucket_name, expected_type=type_hints["bucket_name"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "createUserData", [props, bucket_name]))
 
     @jsii.member(jsii_name="expireAfter")
@@ -622,6 +636,9 @@ class GitlabContainerRunner(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabContainerRunner.expire_after)
+            check_type(argname="argument duration", value=duration, expected_type=type_hints["duration"])
         return typing.cast(None, jsii.invoke(self, "expireAfter", [duration]))
 
     @builtins.property # type: ignore[misc]
@@ -751,6 +768,26 @@ class GitlabContainerRunnerProps:
         '''
         if isinstance(vpc_subnet, dict):
             vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabContainerRunnerProps.__init__)
+            check_type(argname="argument gitlabtoken", value=gitlabtoken, expected_type=type_hints["gitlabtoken"])
+            check_type(argname="argument block_duration", value=block_duration, expected_type=type_hints["block_duration"])
+            check_type(argname="argument docker_volumes", value=docker_volumes, expected_type=type_hints["docker_volumes"])
+            check_type(argname="argument ebs_size", value=ebs_size, expected_type=type_hints["ebs_size"])
+            check_type(argname="argument ec2iamrole", value=ec2iamrole, expected_type=type_hints["ec2iamrole"])
+            check_type(argname="argument ec2type", value=ec2type, expected_type=type_hints["ec2type"])
+            check_type(argname="argument gitlab_runner_image", value=gitlab_runner_image, expected_type=type_hints["gitlab_runner_image"])
+            check_type(argname="argument gitlaburl", value=gitlaburl, expected_type=type_hints["gitlaburl"])
+            check_type(argname="argument instance_interruption_behavior", value=instance_interruption_behavior, expected_type=type_hints["instance_interruption_behavior"])
+            check_type(argname="argument key_name", value=key_name, expected_type=type_hints["key_name"])
+            check_type(argname="argument selfvpc", value=selfvpc, expected_type=type_hints["selfvpc"])
+            check_type(argname="argument spot_fleet", value=spot_fleet, expected_type=type_hints["spot_fleet"])
+            check_type(argname="argument tag1", value=tag1, expected_type=type_hints["tag1"])
+            check_type(argname="argument tag2", value=tag2, expected_type=type_hints["tag2"])
+            check_type(argname="argument tag3", value=tag3, expected_type=type_hints["tag3"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+            check_type(argname="argument valid_until", value=valid_until, expected_type=type_hints["valid_until"])
+            check_type(argname="argument vpc_subnet", value=vpc_subnet, expected_type=type_hints["vpc_subnet"])
         self._values: typing.Dict[str, typing.Any] = {
             "gitlabtoken": gitlabtoken,
         }
@@ -1149,6 +1186,10 @@ class GitlabRunnerAutoscaling(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabRunnerAutoscaling.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabRunnerAutoscalingProps(
             gitlab_token=gitlab_token,
             alarms=alarms,
@@ -1339,6 +1380,23 @@ class GitlabRunnerAutoscalingProps:
         '''
         if isinstance(vpc_subnet, dict):
             vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabRunnerAutoscalingProps.__init__)
+            check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
+            check_type(argname="argument alarms", value=alarms, expected_type=type_hints["alarms"])
+            check_type(argname="argument desired_capacity", value=desired_capacity, expected_type=type_hints["desired_capacity"])
+            check_type(argname="argument docker_volumes", value=docker_volumes, expected_type=type_hints["docker_volumes"])
+            check_type(argname="argument ebs_size", value=ebs_size, expected_type=type_hints["ebs_size"])
+            check_type(argname="argument gitlab_runner_image", value=gitlab_runner_image, expected_type=type_hints["gitlab_runner_image"])
+            check_type(argname="argument gitlab_url", value=gitlab_url, expected_type=type_hints["gitlab_url"])
+            check_type(argname="argument instance_role", value=instance_role, expected_type=type_hints["instance_role"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument max_capacity", value=max_capacity, expected_type=type_hints["max_capacity"])
+            check_type(argname="argument min_capacity", value=min_capacity, expected_type=type_hints["min_capacity"])
+            check_type(argname="argument spot_instance", value=spot_instance, expected_type=type_hints["spot_instance"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnet", value=vpc_subnet, expected_type=type_hints["vpc_subnet"])
         self._values: typing.Dict[str, typing.Any] = {
             "gitlab_token": gitlab_token,
         }
